#ifndef __eefs_defined__
#define __eefs_defined__
typedef struct FileHandleS {
    int sectoraddr;  // Current sector address
    int offset;      // Current offset within a sector 
    int position;    // Current byte position within a file
    int filesize;    // Number of bytes in the file
    int cachedaddr;  // Cached sector address
    long *cacheptr;  // Pointer to the memory cache
    int dirtylow;    // Low offset for a changed value
    int dirtyhigh;   // High offset for a changed value
    int firstaddr;   // First sector address including attribute bits
    int directaddr;  // Address of the file's directory entry
    long buffer[16]; // Sector buffer
} FileHandleT;

struct dirent {
    int attr;
    int filesize;
    char d_name[24];
};

// Global functions
long eefs_mount_explicit(long clkpin, long datpin, long startaddr, long size);
long eefs_hopen(FileHandleT *handle, char *fname, long mode);
long eefs_hclose(FileHandleT *handle);
long eefs_hread(FileHandleT *handle, char *buffer, long num);
long eefs_hwrite(FileHandleT *handle, char *buffer, long num);
long eefs_hgetc(FileHandleT *handle);
long eefs_hputs(FileHandleT *handle, char *buffer);
long eefs_hputc(FileHandleT *handle, long val);
long eefs_hopendir(FileHandleT *handle);
long eefs_hnextfile(FileHandleT *handle, long fbuf);
long eefs_hget_filesize(FileHandleT *handle);
long eefs_hseek(FileHandleT *handle, long newpos);
long eefs_htell(FileHandleT *handle);
long eefs_hflush(FileHandleT *handle);
long eefs_handlesize(void);
long eefs_format(long size);
long eefs_rename(char *fname1, char *fname2);
long eefs_hreaddir(FileHandleT *dirhand);
long eefs_hclosedir(FileHandleT *dirhand);
long eefs_hchdir(char *path);
long eefs_chmod(char *fname, long modebits);

#define ATTR_DIRECTORY 8
#define ATTR_READ      4
#define ATTR_WRITE     2
#define ATTR_EXEC      1

#define MAX_PATH       80
#endif
