/*
############################################################################
# Copyright (c) 2012 Dave Hein
# MIT Licensed
############################################################################
*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include "eefsdir.h"

extern char eefs_currdir[80];

int eefs_mkdir(char *path, int mode)
{
    int result;
    char *fname;
    char path1[MAX_PATH];
    eefs_resolve_path(path, path1);
    fname = eefs_get_rootname(path1);
    if (!fname)
        result = -errno;
    else if ((result = eefs_hmkdir(fname, mode)))
        errno = -result;

    return result;
}

int eefs_rmdir(char *path)
{
    char *fname;
    int result;
    char path1[MAX_PATH];
    struct dirent *entry;
    FileHandleT *pdir = eefs_opendir(path);
    
    if (!pdir)
        return -1;
        
    result = eefs_hreaddir(pdir);
    eefs_closedir(pdir);
    if (result)
    {
        errno = ENOTEMPTY;
        return -1;
    }
    
    eefs_resolve_path(path, path1);
    fname = eefs_get_rootname(path1);
    if (!fname)
        result = -errno;
    else if ((result = eefs_hopen(0, fname, 'D')))
    {
        errno = -result;
        result = -1;
    }
    return result;
}

FileHandleT *eefs_opendir(char *path)
{
    int handlesize = eefs_handlesize();
    FileHandleT *pdir = malloc(handlesize);
    int retval;
    char path1[MAX_PATH];

    eefs_resolve_path(path, path1);

    if (!pdir)
    {
        errno = ENOMEM;
        return 0;
    }

    retval = eefs_hchdir(path1);
    if (retval)
    {
        errno = -retval;
        free(pdir);
        return 0;
    }

    retval = eefs_hopendir(pdir);
    if (retval)
    {
        errno = -retval;
        free(pdir);
        return 0;
    }

    return pdir;
}

struct dirent *eefs_readdir(FileHandleT *pdir)
{
    return (struct dirent *)eefs_hreaddir(pdir);
}

int eefs_closedir(FileHandleT *pdir)
{
    if (!pdir) return -1;
    eefs_hclosedir(pdir);
    free((void *)pdir);
    return 0;
}

int eefs_chdir(char *path)
{
    int retval;
    char path1[MAX_PATH];

    eefs_resolve_path(path, path1);
    if ((retval = eefs_hchdir(path1)))
        errno = -retval;
    else
        strcpy(eefs_currdir, path1);
    return retval;
}

char *eefs_getcwd(char *str, int size)
{
    strncpy(str, eefs_currdir, size);
    return str;
}

/*
+--------------------------------------------------------------------
|  TERMS OF USE: MIT License
+--------------------------------------------------------------------
Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files
(the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge,
publish, distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+------------------------------------------------------------------
*/
